### a piece in the bag

sub new {
    my $class = shift;

    $self = { nextelement => undef, data => undef };
    
    bless $self, $class;
}

sub setNext {
    my ($self, $el) = @_;

    $self->{nextelement} = $el;
}

sub setData {
    my ($self, $d) = @_;

    $self->{data} = $d;
}
