### Blue dither algorithm

use parent 'OnePassBitmapAlgorithm';

sub new {
    my $class = shift;

    $self = SUPER::OnePassBitmapAlgorithm->new;
    
    bless $self, $class;

    $self->init; ### sets bitmap undef
}


