### one pass graphics tools

sub new {
    my $class = shift;

    $self = { algorithm => undef,  };
    
    bless $self, $class;
}

sub run {
    my ($self, $executable) = @_;

    ### FIXME run the OnePassAlgorithm
    
}

1;
