### a bitmap with a matrix as data structure

sub new {
    my $class = shift;

    $self = { matrix => undef, };

    bless $self, $class;

};

sub setMatrix {
    my ($self, $m) = @_;

    $self->{matrix} = $m;

}

1;
    
