### filename loader for a 3D bitmap/model

sub new {
    my $class = shift;

    $self = { algorithm => undef };
    
    bless $self, $class;
}

sub loadDAEFile {
    my ($self, $aedfilename) = @_;
    

    ### FIXME

}

1;
