### load a bitmap from file the put it in a matrix

sub new {
    my $class = shift;

    $self = { };

    bless $self, $class;

}

sub loadPNGFile {
    my ($self, $pngfilename) = @_;
    
    my $matrix;

    ### FIXME use png on cpan
    return $matrix;
}

1;
